@@ -16,11 +16,13 @@ import warnings
 
 
 class CloudConfig(object):
-    def __init__(self, name, region, config, prefer_ipv6=False):
+    def __init__(self, name, region, config,
+                 prefer_ipv6=False, auth_plugin=None):
         self.name = name
         self.region = region
         self.config = config
         self._prefer_ipv6 = prefer_ipv6
+        self._auth = auth_plugin
 
     def __getattr__(self, key):
         """Return arbitrary attributes."""
@@ -106,3 +108,7 @@ class CloudConfig(object):
     @property
     def prefer_ipv6(self):
         return self._prefer_ipv6
+
+    def get_auth(self):
+        """Return a keystoneauth plugin from the auth credentials."""
+        return self._auth
